@@ -1,5 +1,5 @@
 /**
- * Copyright (c) Istituto Nazionale di Fisica Nucleare, 2006-2012.
+ * Copyright (c) Istituto Nazionale di Fisica Nucleare, 2006-2014.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -28,19 +28,20 @@ import org.w3c.dom.Document;
 
 public class XMLUtils {
 
-	public static String documentAsString(Document doc){
-	
-		try {
-			Transformer transformer = TransformerFactory.newInstance().newTransformer();
-			transformer.setOutputProperty(OutputKeys.INDENT, "yes");
-			StreamResult result = new StreamResult(new StringWriter());
-			DOMSource source = new DOMSource(doc);
-			transformer.transform(source, result);
-			return result.getWriter().toString();
-		
-		} catch (Throwable e) {
-			throw new VOMSError(e.getMessage(), e);
-		}
-		
-	}
+  public static String documentAsString(Document doc) {
+
+    try {
+      Transformer transformer = TransformerFactory.newInstance()
+        .newTransformer();
+      transformer.setOutputProperty(OutputKeys.INDENT, "yes");
+      StreamResult result = new StreamResult(new StringWriter());
+      DOMSource source = new DOMSource(doc);
+      transformer.transform(source, result);
+      return result.getWriter().toString();
+
+    } catch (Throwable e) {
+      throw new VOMSError(e.getMessage(), e);
+    }
+
+  }
 }
